#!/usr/bin/env python

"""
  to test with python

cmd1:env keystore=`pwd` ./attr.py 
"""

import os
import ABAC

keystore=os.environ["keystore"]

ctxt = ABAC.Context()
print "ABAC version %s" % ctxt.version()

ctxt.load_directory(keystore)

out = ctxt.context_principals()
print "...initial principal set..."
for x in out[1]:
    print "%s " % x.string()
print "\n" 

out = ctxt.context_credentials()
print "...initial policy attribute set..."
for c in out[1]:
    print "%s <- %s" % (c.head_string(), c.tail_string())
print "\n"

alphaID=ABAC.ID("Alpha_ID.pem");
alphaID.id_load_privkey_file("Alpha_private.pem");
alpha=alphaID.id_keyid()

bobID=ABAC.ID("Bob_ID.pem");
bobID.id_load_privkey_file("Bob_private.pem");
bob=bobID.id_keyid()

maryannID=ABAC.ID("Maryann_ID.pem");
maryannID.id_load_privkey_file("Maryann_private.pem");
maryann=maryannID.id_keyid()

joeID=ABAC.ID("Joe_ID.pem");
joeID.id_load_privkey_file("Joe_private.pem");
joe=joeID.id_keyid()

################################################
# [keyid:alpha].role:payRaise <-
#      [keyid:alpha].role:evaluatorOf([principal:?this]).role:goodPerformance &
#      [keyid:alpha].role:managerOf([principal:?this]).role:niceCoworker
head=ABAC.Role(alpha,"payRaise")
param=ABAC.DataTerm("principal", "This")
tail1 = ABAC.Role(alpha,"evaluatorOf","goodPerformance")
tail1.role_add_linked_data_term(param)
param=ABAC.DataTerm("principal", "This")
tail2 = ABAC.Role(alpha,"managerOf","niceCoworker")
tail2.role_add_linked_data_term(param)
attr=ABAC.Attribute(head, 1800)
attr.attribute_add_tail(tail1)
attr.attribute_add_tail(tail2)
attr.attribute_bake()
attr.attribute_write_cert("Alpha_payraise__Alpha_performance_qT_niceguy_qT_attr.der")
ctxt.load_attribute_file("Alpha_payraise__Alpha_performance_qT_niceguy_qT_attr.der")
print attr.string() 
print attr.typed_string()
print "\n"

#################################################
# [keyid:alpha].role:managerOf([principal:?Z])<-
#           [keyid:alpha].role:evaluatorOf([principal:?Z])
param=ABAC.DataTerm("principal", "Z")
head=ABAC.Role(alpha,"managerOf")
head.role_add_data_term(param)
param=ABAC.DataTerm("principal", "Z")
tail = ABAC.Role(alpha,"evaluatorOf")
tail.role_add_data_term(param)
attr=ABAC.Attribute(head, 1800)
attr.attribute_add_tail(tail)
attr.attribute_bake()
attr.attribute_write_cert("Alpha_manager_qZ__Alpha_evaluator_qZ_attr.der")
ctxt.load_attribute_file("Alpha_manager_qZ__Alpha_evaluator_qZ_attr.der")
print attr.string() 
print attr.typed_string()
print "\n"

#################################################
# [keyid:alpha].role:evaluatorOf([keyid:Maryann]) <-[keyid:Bob]
param=ABAC.DataTerm(maryannID)
head = ABAC.Role(alpha,"evaluatorOf")
head.role_add_data_term(param)
tail = ABAC.Role(bob)
attr=ABAC.Attribute(head, 1800)
attr.attribute_add_tail(tail)
attr.attribute_bake()
attr.attribute_write_cert("Alpha_evaluator_m__Bob_attr.der")
ctxt.load_attribute_file("Alpha_evaluator_m__Bob_attr.der")
print attr.string() 
print attr.typed_string()
print "\n"

#################################################
# [keyid:Bob].role:goodPerformance <- [keyid:Maryann])
head = ABAC.Role(bob,"goodPerformance")
tail = ABAC.Role(maryann)
attr=ABAC.Attribute(head, 1800)
attr.attribute_add_tail(tail)
attr.attribute_bake()
attr.attribute_write_cert("Bob_goodperformance__Maryann_attr.der")
ctxt.load_attribute_file("Bob_goodperformance__Maryann_attr.der")
print attr.string() 
print attr.typed_string()
print "\n"

#################################################
# [keyid:Bob].role:niceCoworker <- [keyid:Maryann])
head = ABAC.Role(bob,"niceCoworker")
tail = ABAC.Role(maryann)
attr=ABAC.Attribute(head, 1800)
attr.attribute_add_tail(tail)
attr.attribute_bake()
attr.attribute_write_cert("Bob_nicecoworker__Maryann_attr.der")
ctxt.load_attribute_file("Bob_nicecoworker__Maryann_attr.der")
print attr.string() 
print attr.typed_string()
print "\n"

#################################################
# [keyid:alpha].role:evaluatorOf([keyid:Joe]) <-[keyid:Bob]
param=ABAC.DataTerm(joeID)
head = ABAC.Role(alpha,"evaluatorOf")
head.role_add_data_term(param)
tail = ABAC.Role(bob)
attr=ABAC.Attribute(head, 1800)
attr.attribute_add_tail(tail)
attr.attribute_bake()
attr.attribute_write_cert("Alpha_evaluator_j__Bob_attr.der")
ctxt.load_attribute_file("Alpha_evaluator_j__Bob_attr.der")
print attr.string() 
print attr.typed_string()
print "\n"

#################################################
# [keyid:Bob].role:goodPerformance <- [keyid:Joe])
head = ABAC.Role(bob,"goodPerformance")
tail = ABAC.Role(joe)
attr=ABAC.Attribute(head, 1800)
attr.attribute_add_tail(tail)
attr.attribute_bake()
attr.attribute_write_cert("Bob_goodperformance__Joe_attr.der")
ctxt.load_attribute_file("Bob_goodperformance__Joe_attr.der")
print attr.string() 
print attr.typed_string()
print "\n"


ctxt.dump_yap_db()
##
